// GET END ITEMS OF A PROJECT DEFINED BY NAME
// Please provide connectin details in file settings.js
// Author: Sven Dickmans, Autodesk

/* --------------------------------------------------------------------------------------------------------
    Change Log
    - 2022-01-24: Initial version
   -------------------------------------------------------------------------------------------------------- */


// Options
const projectName   =  'New Order';
const bomType       = 'ALL';    // Available values : ALL, ALL_WORKING, ALL_RELEASE, LATEST_WORKING, LATEST_RELEASE, EFFECTIVE_DATE


const axios     = require('axios');
const settings  = require('./settings.js');
const utils     = require('./utils.js');


utils.printStart([['Project Name', projectName]]);

utils.login(function(companyID) {
    getProjectID(companyID, function(projectId) {
        getProjectEndItems(projectId, function() {
            utils.printEnd();
        });
    });
});



function getProjectID(companyID, callback) {
    
    axios.get('https://live.upchain.net/api/project/v1/projects?companyID=' + companyID).then(function (response) {
        
        console.log('    Found ' + response.data.length + ' projects');
        console.log();
        
        let projectId = null;
        
        for(project of response.data) {
            if(project.name === projectName) {
                projectId = project.id;
            }
        }
        
        if(projectId === null) console.log('    Project ' + projectName + ' could not be found');
        
        callback(projectId);

    }).catch(function (error) {
        console.log(error);
    });
    
}


function getProjectEndItems(projectId, callback) {
    
    if(projectId === null) callback();
        
    // axios.get('https://live.upchain.net/api/bom/v1/project/'  + projectId + '?treeType=' + bomType).then(function (response) {
    axios.get('https://live.upchain.net/api/bom/v2/projects/end-items?id=' + projectId + '&filter=' + bomType).then(function (response) {

        console.log(response.data[projectId]);

        console.log('    Found ' + response.data[projectId].length + ' end items');
        console.log('    -----------------------------------------------------------------------------');
        console.log('    name / majorRevision / minorRevision / id');
        console.log();
        
        for(item of response.data[projectId]) {
            console.log('    ' + item.name +  ' ' + item.majorRevision + '-' + item.minorRevision + ' ( ' + item.id + ')');
        }
        
        callback();

    }).catch(function (error) {
        console.log(error);
    });
    
}