// GET EBOMS OF A PROJECT DEFINED BY NAME

// Last Modification Date : Jul 13, 2021
/* ----------------------------------------------------
     Change Log
     - 2021-07-13: Initial version
 */


const projectName   =  'Genesis';
const bomType       = 'LATEST_RELEASE';    // Available values : ALL, ALL_WORKING, ALL_RELEASE, LATEST_WORKING, LATEST_RELEASE, EFFECTIVE_DATE



const axios         = require('axios');
const querystring   = require('querystring');
const settings      = require('./settings.js');
let index           = 0;


console.log('   ');
console.log('   *********************************** START ***********************************');
console.log('   ');
console.log('    SETTINGS');
console.log('   -----------------------------------------------------------------------------');
console.log('    Client ID     : ' + settings.clientId); 
console.log('    User Name     : ' + settings.username); 
console.log('    Project Name  : ' + projectName); 
console.log('   '); 


login(function() {
    getCompanies(function(companyID) {
        getProjectID(companyID, function(projectId) {
            getProjectEndItems(projectId, function(endItems) {
                getProjectEBOMs(projectId, endItems);
            });
        });
    });
});


function login(callback) {
    
    let params = {
        'grant_type'    : 'password',
        'client_id'     : settings.clientId,
        'client_secret' : settings.clientSecret,
        'username'      : settings.username,
        'password'      : settings.password
    }
    
    axios.post('https://live-sso.upchain.net/auth/realms/upchain/protocol/openid-connect/token', querystring.stringify(params)).then(function (response) {
        
        if(response.status === 200) {
            console.log('    Login successful');
            axios.defaults.headers.common['Authorization']  = "Bearer " + response.data.access_token;
            callback();
        } else {
            console.log('    Login failed');   
            console.log('   ');
        }

    }).catch(function (error) {
        console.log(error);
    });
    
}


function getCompanies(callback) {
    
    axios.get('https://live.upchain.net/api/auth/v1/companies').then(function (response) {
        
        if(response.data.length > 0)  {

            if(response.data.length > 1)  console.log('    Found ' + response.data.length + ' companies');
                                    else  console.log('    Found 1 company');
            
            console.log('    Using company ' + response.data[0].name + ' (' + response.data[0].id + ')');
            axios.defaults.headers.common['Upc-Selected-Company']  = response.data[0].id;
            callback(response.data[0].id);
            
        } else {
            console.log('    Coulld not find related companies');   
            console.log('   ');           
        }

    }).catch(function (error) {
        console.log(error);
    });
    
}


function getProjectID(companyID, callback) {
    
    axios.get('https://live.upchain.net/api/project/v1/projects?companyID=' + companyID).then(function (response) {
        
        console.log('    Found ' + response.data.length + ' projects');
        console.log();
        
        let projectId = null;
        
        for(project of response.data) {
            if(project.name === projectName) {
                projectId = project.id;
            }
        }
        
        if(projectId === null) console.log('    Project ' + projectName + ' could not be found');
        
        callback(projectId);

    }).catch(function (error) {
        console.log(error);
    });
    
}


function getProjectEndItems(projectId, callback) {
    
    if(projectId === null) callback();
        
    axios.get('https://live.upchain.net/api/bom/v1/project/'  + projectId + '?treeType=' + bomType).then(function (response) {

        let endItems = [];

        // console.log(response.data);

        console.log('    Found ' + response.data.length + ' end items');
        console.log('   -----------------------------------------------------------------------------');
        console.log('    partNumber / partName / partMajorRevision / partMinorRevision / status / partType / id');
        console.log();
        
        for(item of response.data) {
            let partversion = item.partVersionDO;
            console.log('    ' + partversion.partNumber + ' | ' + partversion.partName + ' | ' + partversion.partMajorRevision + ' | ' + partversion.partMinorRevision + ' | ' + partversion.status + ' | ' + partversion.partType + ' | ' + partversion.id);

            endItems.push(partversion);

        }
        
        callback(endItems);

    }).catch(function (error) {
        console.log(error);
    });
    
}


function getProjectEBOMs(projectId, endItems) {


    if(index < endItems.length) {

        getProjectEBOM(projectId, endItems[index++], function() {
            getProjectEBOMs(projectId, endItems);
        });

    } else {

        console.log('   ');
        console.log('   ************************************ END ************************************');
        console.log('   ');

    };

}

function getProjectEBOM(projectId, endItem, callback) {
    
    let url = 'https://live.upchain.net/api/bom/v1/project/'  + projectId + '/part_version/' + endItem.id + '/ebom?bomRevision=' + endItem.lastBomRevision + '&latestWorking=false&showDeleted=false&suppressed=false';

    if(endItem.lastBomRevision === null) {
        
        console.log();
        console.log('    Item ' + endItem.partName + ' does not have a BOM');
        console.log();

        callback();

    } else {

        axios.get(url).then(function (response) {

            console.log('    Showing ' + response.data[0].children.length + ' BOM items of ' + endItem.partName);
            console.log('   -----------------------------------------------------------------------------');
            console.log('    partPart.sortNumber / partPart.quantity / partPart.id / partPart.pbPartVersion.itemNumber / partPart.pbPartVersion.partName / partPart.pbPartVersion.partType / children.length');

            for(child of response.data[0].children) {
                console.log('    ' + child.partPart.sortNumber + ' | ' + child.partPart.quantity + ' | ' + child.partPart.id + ' | ' + child.partPart.pbPartVersion.itemNumber + ' | ' + child.partPart.pbPartVersion.partName + ' | ' + child.partPart.pbPartVersion.partType + ' | ' + child.children.length);
            }

            console.log();
            
            callback();

        }).catch(function (error) {
            console.log(error);
        });

    }
    
}