// GET SCHEDULE OF DEFINED PROJECT

// Last Modification Date : Jul 13, 2021
/* ----------------------------------------------------
     Change Log
     - 2021-07-13: Initial version
 */



const projectName =  'Genesis';


const axios         = require('axios');
const querystring   = require('querystring');
const settings      = require('./settings.js');


console.log('   ');
console.log('   *********************************** START ***********************************');
console.log('   ');
console.log('    SETTINGS');
console.log('   -----------------------------------------------------------------------------');
console.log('    Client ID     : ' + settings.clientId); 
console.log('    User Name     : ' + settings.username); 
console.log('    Project Name  : ' + projectName); 
console.log('   '); 


login(function() {
    getCompanyID(function(companyID) {
        getProjectID(companyID, function(projectId) {
            getProjectSchedule(projectId, function() {
                
                console.log('   ');
                console.log('   ************************************ END ************************************');
                console.log('   ');

            });
        });
    });
});


function login(callback) {
    
    let params = {
        'grant_type'    : 'password',
        'client_id'     : settings.clientId,
        'client_secret' : settings.clientSecret,
        'username'      : settings.username,
        'password'      : settings.password
    }
    
    axios.post('https://live-sso.upchain.net/auth/realms/upchain/protocol/openid-connect/token', querystring.stringify(params)).then(function (response) {
        
        if(response.status === 200) {
            console.log('    Login successful');
            axios.defaults.headers.common['Authorization']  = "Bearer " + response.data.access_token;
            callback();
        } else {
            console.log('    Login failed');   
            console.log('   ');
        }

    }).catch(function (error) {
        console.log(error);
    });
    
}


function getCompanyID(callback) {
    
    axios.get('https://live.upchain.net/api/auth/v1/companies').then(function (response) {
        
        if(response.data.length > 0)  {

            console.log();
            if(response.data.length > 1)  console.log('    Found ' + response.data.length + ' companies');
                                    else  console.log('    Found 1 company');
            
            console.log('    Using company ' + response.data[0].name + ' (' + response.data[0].id + ')');
            axios.defaults.headers.common['Upc-Selected-Company']  = response.data[0].id;
            callback(response.data[0].id);
            
        } else {
            console.log('    Could not find related companies');   
            console.log('   ');           
        }

    }).catch(function (error) {
        console.log(error);
    });
    
}


function getProjectID(companyID, callback) {
    
    axios.get('https://live.upchain.net/api/project/v1/projects?companyID=' + companyID).then(function (response) {
        
        console.log();
        console.log('    Found ' + response.data.length + ' projects');
        
        let projectId = null;
        
        for(project of response.data) {
            if(project.name === projectName) {
                projectId = project.id;

                console.log('    Using project ' + project.name + ' (' + project.id + ')');

            }
        }
        
        if(projectId === null) console.log('    Project ' + projectName + ' could not be found');
        
        callback(projectId);

    }).catch(function (error) {
        console.log(error);
    });
    
}


function getProjectSchedule(projectId, callback) {
    
    if(projectId === null) callback();

    let url = 'https://live.upchain.net/api/v1/activity/projects/' + projectId + '/activities';

    axios.get(url).then(function (response) {

        console.log();
        console.log('    Found ' + response.data.length + ' activities');
        console.log('   -----------------------------------------------------------------------------');
        console.log('    id / activityTypeVersionName / text / planned_start / planned_end');
        
        for(activity of response.data) {
            console.log('    ' + activity.id + ' | ' + activity.activityTypeVersionName + ' | ' + activity.text + ' | ' + activity.planned_start + ' | ' + activity.planned_end);
        }
        
        callback();

    }).catch(function (error) {
        console.log(error);
    });
    
}