// GET DETAILS OF A PROJECT DEFINED BY NAME
// Please provide connectin details in file settings.js
// Author: Sven Dickmans, Autodesk

/* --------------------------------------------------------------------------------------------------------
    Change Log
    - 2022-01-27: Initial version
   -------------------------------------------------------------------------------------------------------- */


// Options
const projectName =  'New Order';


const axios     = require('axios');
const utils     = require('./utils.js');

utils.printStart([['Project Name', projectName]]);

utils.login(function(companyID) {
    getProjectID(companyID, function(projectId) {
        getProjectDetails(projectId, function() {
            utils.printEnd();
        });
    });
});


function getProjectID(companyID, callback) {
    
    axios.get('https://live.upchain.net/api/project/v1/projects?companyID=' + companyID).then(function (response) {
        
        console.log();
        console.log('    Found ' + response.data.length + ' projects');
        
        let projectId = null;
        
        for(project of response.data) {
            if(project.name === projectName) {
                projectId = project.id;

                console.log('    Using project ' + project.name + ' (' + project.id + ')');

            }
        }
        
        if(projectId === null) console.log('    Project ' + projectName + ' could not be found');
        
        callback(projectId);

    }).catch(function (error) {
        console.log(error);
    });
    
}


function getProjectDetails(projectId, callback) {
    
    if(projectId === null) callback();
        
    axios.get('https://live.upchain.net/api/project/v2/projects/' + projectId + '/details').then(function (response) {
        console.log(response.data);
        callback();
    }).catch(function (error) {
        console.log(error);
    });
    
}