// SEARCH DOCUMENTS
// Please provide connectin details in file settings.js
// Author: Sven Dickmans, Autodesk

/* --------------------------------------------------------------------------------------------------------
    Change Log
    - 2022-01-27: Initial version
   -------------------------------------------------------------------------------------------------------- */


// Options
const projectName =  'New Order';


const axios     = require('axios');
const utils     = require('./utils.js');


utils.printStart([['Project Name', projectName]]);

utils.login(function(companyID) {
    getProjectID(companyID, function(projectId) {
        searchDocuments(projectId, function() {
            utils.printEnd();
        });
    });
});


function getProjectID(companyID, callback) {
    
    axios.get('https://live.upchain.net/api/project/v1/projects?companyID=' + companyID).then(function (response) {
        
        console.log();
        console.log('    Found ' + response.data.length + ' projects');
        
        let projectId = null;
        
        for(project of response.data) {
            if(project.name === projectName) {
                projectId = project.id;

                console.log('    Using project ' + project.name + ' (' + project.id + ')');

            }
        }
        
        if(projectId === null) console.log('    Project ' + projectName + ' could not be found');
        
        callback(projectId);

    }).catch(function (error) {
        console.log(error);
    });
    
}


function searchDocuments(projectId, callback) {
    
    if(projectId === null) callback();

    let url = 'https://live.upchain.net/api/dms/v1/document/search';

    axios.post(url, {
        'searchCriteria' : [{
            'ignoreCase'    : true,
            'operator'      : '=',
            values          : [ 'BOM.xls' ]
        }],
        'projectId' : projectId
    }).then(function (response) {

        // console.log(response.data);

        console.log();
        console.log('    Found ' + response.data.nodes.length + ' documents');
        console.log('   -----------------------------------------------------------------------------');
        console.log('    id / documentId / documentVersionId / document.documentNumber / document.modifiedOn');
        
        for(item of response.data.nodes) {
            console.log('    ' + item.id + ' | ' + item.documentId + ' | ' + item.documentVersionId + ' | ' + item.document.documentNumber + ' | ' + item.document.modifiedOn);
        }
        
        callback();

    }).catch(function (error) {
        console.log(error);
    });
    
}