// SEARCH DOCUMENTS
// Please provide connectin details in file settings.js
// Author: Sven Dickmans, Autodesk

/* --------------------------------------------------------------------------------------------------------
    Change Log
    - 2022-01-27: Initial version
   -------------------------------------------------------------------------------------------------------- */


// Options
const projectName =  'New Order';


const axios     = require('axios');
const utils     = require('./utils.js');


utils.printStart([['Project Name', projectName]]);

utils.login(function(companyID) {
    getProjectID(companyID, function(projectId) {
        searchDocuments(projectId, function() {
            utils.printEnd();
        });
    });
});


function getProjectID(companyID, callback) {
    
    axios.get('https://live.upchain.net/api/project/v1/projects?companyID=' + companyID).then(function (response) {
        
        console.log();
        console.log('    Found ' + response.data.length + ' projects');
        
        let projectId = null;
        
        for(project of response.data) {
            if(project.name === projectName) {
                projectId = project.id;

                console.log('    Using project ' + project.name + ' (' + project.id + ')');

            }
        }
        
        if(projectId === null) console.log('    Project ' + projectName + ' could not be found');
        
        callback(projectId);

    }).catch(function (error) {
        console.log(error);
    });
    
}


function searchDocuments(projectId, callback) {
    
    if(projectId === null) callback();

    let url = 'https://live.upchain.net/api/dms/v1/document/search_extended';

    axios.post(url, {
        'searchCriteria' : [{
            'attribute'     : 'originalName',
            'ignoreCase'    : true,
            'operator'      : '=',
            'values'        : [ 'Business Plan.xlsx' ]
        }],
        'projectId' : projectId
    }).then(function (response) {

        console.log();
        console.log('    ' + response.data.length + ' results found');
        console.log();

        for(item of response.data) {
            console.log(item);
        }
        
        callback();

    }).catch(function (error) {
        console.log(error);
    });
    
}