// SEARCH DOCUMENTS AND RETRIEVE DETAILS OF FIRST ENTRY
// Please provide connectin details in file settings.js
// Author: Sven Dickmans, Autodesk

/* --------------------------------------------------------------------------------------------------------
    Change Log
    - 2022-02-01: Initial version
   -------------------------------------------------------------------------------------------------------- */


// Options
const projectName =  'New Order';


const axios     = require('axios');
const utils     = require('./utils.js');


utils.printStart([['Project Name', projectName]]);

utils.login(function(companyID) {
    getProjectID(companyID, function(projectId) {
        searchDocuments(projectId, function(documentVersionId) {
            getDocumentMetadata(projectId, documentVersionId, function() {
                getDocumentStatus(documentVersionId, function() {
                    getDocumentTree(documentVersionId, function() {
                        utils.printEnd();
                    });
                });
            });
        });
    });
});


function getProjectID(companyID, callback) {
    
    axios.get('https://live.upchain.net/api/project/v1/projects?companyID=' + companyID).then(function (response) {
        
        console.log();
        console.log('    Found ' + response.data.length + ' projects');
        
        let projectId = null;
        
        for(project of response.data) {
            if(project.name === projectName) {
                projectId = project.id;

                console.log('    Using project ' + project.name + ' (' + project.id + ')');

            }
        }
        
        if(projectId === null) console.log('    Project ' + projectName + ' could not be found');
        
        callback(projectId);

    }).catch(function (error) {
        console.log(error);
    });
    
}


function searchDocuments(projectId, callback) {
    
    if(projectId === null) callback();

    let url = 'https://live.upchain.net/api/dms/v1/document/search';

    axios.post(url, {
        'searchCriteria' : [{
            'ignoreCase'    : true,
            'operator'      : '=',
            'attribute'     : 'Original File Name',
            values          : [ 'BOM.xlsx' ]
        }],
        'projectId' : projectId
    }).then(function (response) {

        console.log();
        console.log('    Found ' + response.data.nodes.length + ' documents');
        console.log('   -----------------------------------------------------------------------------');
        console.log('    id / documentId / documentVersionId / document.documentNumber / document.modifiedOn');
        
        for(item of response.data.nodes) {
            console.log('    ' + item.id + ' | ' + item.documentId + ' | ' + item.documentVersionId + ' | ' + item.document.documentNumber + ' | ' + item.document.modifiedOn);
        }

        let result = (response.data.nodes.length > 0) ? response.data.nodes[0].documentVersionId : '';
        
        callback(result);

    }).catch(function (error) {
        console.log(error);
    });
    
}


function getDocumentMetadata(projectId, documentVersionId, callback) {
    
    if(projectId === '') callback();
    if(documentVersionId === '') callback();

    let url = 'https://live.upchain.net/api/dms/v1/document/' + documentVersionId + '/metadata?projectId=' + projectId;

    axios.get(url).then(function (response) {
        
        console.log();
        console.log('    /metadata');
        console.log('   -----------------------------------------------------------------------------');
        console.log(response.data);

        callback();
    }).catch(function (error) {
        console.log(error);
    });
    
}


function getDocumentStatus(documentVersionId, callback) {
    
    if(documentVersionId === '') callback();

    let url = 'https://live.upchain.net/api/dms/v1/document/' + documentVersionId + '/status';

    axios.get(url).then(function (response) {
        
        console.log();
        console.log('    /status');
        console.log('   -----------------------------------------------------------------------------');
        console.log(response.data);

        callback();
    }).catch(function (error) {
        console.log(error);
    });
    
}


function getDocumentTree(documentVersionId, callback) {
    
    if(documentVersionId === '') callback();

    let url = 'https://live.upchain.net/api/dms/v1/document/' + documentVersionId + '/tree';

    axios.get(url).then(function (response) {
        
        console.log();
        console.log('    /tree');
        console.log('   -----------------------------------------------------------------------------');
        console.log(response.data);

        callback();
    }).catch(function (error) {
        console.log(error);
    });
    
}