// GET EBOM OF ITEM WITH ATTRIBUTES
// Please provide connectin details in file settings.js
// Author: Sven Dickmans, Autodesk

/* --------------------------------------------------------------------------------------------------------
    Change Log
    - 2022-01-27: Initial version
   -------------------------------------------------------------------------------------------------------- */


// Options
const partVersionId     =  '605060';
const projectName       =  'New Order';
const bomRevision       = '1';
const eBomFilter        = 'AS_SAVED' //Available values : LATEST_WORKING, LATEST_RELEASED, VIRTUAL_LATEST_RELEASED, AS_SAVED, EFFECTIVE_DATE


const axios     = require('axios');
const utils     = require('./utils.js');


utils.printStart([['Part Version ID', partVersionId]]);

utils.login(function(companyID) {
    getProjectID(companyID, function(projectId) {
        getItemEBOM(projectId, function() {
            utils.printEnd();
        });
    });
});


function getProjectID(companyID, callback) {
    
    axios.get('https://live.upchain.net/api/project/v1/projects?companyID=' + companyID).then(function (response) {
        
        console.log('    Found ' + response.data.length + ' projects');
        console.log();
        
        let projectId = null;
        
        for(project of response.data) {
            if(project.name === projectName) {
                projectId = project.id;
            }
        }
        
        if(projectId === null) console.log('    Project ' + projectName + ' could not be found');
        
        callback(projectId);

    }).catch(function (error) {
        console.log(error);
    });
    
}


function getItemEBOM(projectId, callback) {
    
    axios.get('https://live.upchain.net/api/bom/v2/project/' + projectId + '/extended-items/' + partVersionId + '?bomRevision=' + bomRevision + '&eBomFilter=' + eBomFilter).then(function (response) {

        console.log(response.data);
    
        console.log('    Found ' + response.data.length + ' bom items');
        console.log('    -----------------------------------------------------------------------------');
        console.log('    name / partMajorRevision / partMinorRevision / id');
        console.log();
        
        for(item of response.data) {
            console.log('    ' + item.name +  ' ' + item.partMajorRevision + '-' + item.partMinorRevision + ' ( ' + item.id + ')');
        }
        
        callback();

    }).catch(function (error) {
        console.log(error);
    });
    
}