// UPDATE ITEM SET ACTUAL COST (FROM ERP)
// Please provide connectin details in file settings.js
// Author: Sven Dickmans, Autodesk

/* --------------------------------------------------------------------------------------------------------
    Change Log
    - 2022-01-24: Initial version
   -------------------------------------------------------------------------------------------------------- */


// Options
let itemNumber          = '63-4015'; // See field Item Number
let itemMajorRevision   = 'XX';    
let supplierName        = 'TRS Tech'; // Supplier name as shown in UI
let costValue           = 11.87;
let divisionNum         = 'DIV1000374'; // use script 99 to retrieve internal num of division
let currencyCode        = 'EUR';



const axios     = require('axios');
const settings  = require('./settings.js');
const utils     = require('./utils.js');


utils.printStart([['itemNumber', itemNumber], ['supplier', supplierName], ['division', divisionNum]]);

utils.login(function(companyID) {
    setItemActualCost(function() {
        utils.printEnd();
    });
});


function setItemActualCost(callback) {
    
    console.log();

    axios.patch('https://live.upchain.net/api/erp/v1/part/' + itemNumber + '/cost', {
        'partMajorRevision': itemMajorRevision,
        'supplierName': supplierName,
        'costValue': costValue,
        'divisionNum': divisionNum,
        'currencyCode': currencyCode
    }).then(function (response) {
        if(response.data.result === 1) {
            console.log('    SUCCESS');
        } else if(response.data.result === 216) {
            console.log('    ERROR : Division is not present (divisionNum = ' + divisionNum + ')');
        } else if(response.data.result === 218) {
            console.log('    ERROR : Actual cost is set already');
        } else {
            console.log('    ERROR with return code ' + response.data.result);
        }

        callback();
    }).catch(function (error) {
        console.log(error);
    });
    
}