// GET LIST OF TRANSLATIONS OF DEFINED ITEM
// Please provide connectin details in file settings.js
// Author: Sven Dickmans, Autodesk

/* --------------------------------------------------------------------------------------------------------
    Change Log
    - 2022-02-08: Initial version
   -------------------------------------------------------------------------------------------------------- */


// Options
const partVersionId   =  '621168';    // grab id from item's URL in the web UI


const axios     = require('axios');
const utils     = require('./utils.js');
const fs        = require('fs');


utils.printStart([['Part Version Id', partVersionId]]);

utils.login(function() {
    getItemPrimaryFile(function(file) {
        downloadPrimaryFile(file);
    });
});


function getItemPrimaryFile(callback) {
    
    axios.get('https://live.upchain.net/api/bom/v1/part_version/' + partVersionId + '/latest_primary_file_version_object').then(function (response) {

        console.log('    File Version Id : ' + response.data.data.PbFileVersionId);
        console.log();
        callback(response.data.data);

    }).catch(function (error) {
        console.log(error);
    });
    
}


const downloadPrimaryFile = async (file) => {

    try {
        const response = await axios({
            method        : 'GET',
            url           : 'https://live.upchain.net/api/bom/v1/file_version/' + file.PbFileVersionId + '/download',
            responseType  : 'stream',
        });

        await response.data.pipe(fs.createWriteStream(file.PbFileUploadFileName));
        
        console.log('    Successfully downloaded ' + file.PbFileUploadFileName);
        utils.printEnd();
        
    } catch (err) {
        throw new Error(err);
    }
    
};
