// GET DETAILS OF FIRST MANUFCTURER FOUND
// Please provide connectin details in file settings.js
// Author: Sven Dickmans, Autodesk

/* --------------------------------------------------------------------------------------------------------
    Change Log
    - 2022-01-19: Initial version
   -------------------------------------------------------------------------------------------------------- */


const axios         = require('axios');
const querystring   = require('querystring');
const settings      = require('./settings.js');
let index           = 0;


console.log('   ');
console.log('   *********************************** START ***********************************');
console.log('   ');
console.log('    SETTINGS');
console.log('   -----------------------------------------------------------------------------');
console.log('    Client ID     : ' + settings.clientId); 
console.log('    User Name     : ' + settings.username); 
console.log('   '); 


login(function() {
    getCompanies(function(companyID) {
        getManufacturers(function(manufacturerID) {
            getManufacturerDetails(manufacturerID, function() {
                    
                console.log('   ');
                console.log('   ************************************ END ************************************');
                console.log('   ');

            });
        });
    });
});


function login(callback) {
    
    let params = {
        'grant_type'    : 'password',
        'client_id'     : settings.clientId,
        'client_secret' : settings.clientSecret,
        'username'      : settings.username,
        'password'      : settings.password
    }
    
    axios.post('https://live-sso.upchain.net/auth/realms/upchain/protocol/openid-connect/token', querystring.stringify(params)).then(function (response) {
        
        if(response.status === 200) {
            console.log('    Login successful');
            axios.defaults.headers.common['Authorization']  = "Bearer " + response.data.access_token;
            callback();
        } else {
            console.log('    Login failed');   
            console.log('   ');
        }

    }).catch(function (error) {
        console.log(error);
    });
    
}


function getCompanies(callback) {
    
    axios.get('https://live.upchain.net/api/auth/v1/companies').then(function (response) {
        
        if(response.data.length > 0)  {

            if(response.data.length > 1)  console.log('    Found ' + response.data.length + ' companies');
                                    else  console.log('    Found 1 company');
            
            console.log('    Using company ' + response.data[0].name + ' (' + response.data[0].id + ')');
            axios.defaults.headers.common['Upc-Selected-Company']  = response.data[0].id;
            callback(response.data[0].id);
            
        } else {
            console.log('    Could not find related companies');   
            console.log('   ');           
        }

    }).catch(function (error) {
        console.log(error);
    });
    
}


function getManufacturers(callback) {
    
    axios.get('https://live.upchain.net/api/v2/manufacturers').then(function (response) {

        console.log('    Found ' + response.data.content.length + ' manufacturers');
        console.log('    Requesting details of manufacturer ' + response.data.content[0].name + ' (' + response.data.content[0].id) + ')';
        console.log();

        callback(response.data.content[0].id);

    }).catch(function (error) {
        console.log(error);
    });
    
}

function getManufacturerDetails(manufacturerID, callback) {

    if(manufacturerID === null) callback();
        
    axios.get('https://live.upchain.net/api/v2/manufacturers/' + manufacturerID).then(function (response) {

        console.log(response.data);
        callback();

    }).catch(function (error) {
        console.log(error);
    });
    
}