// GET RELEVANT IDS
// Please provide connectin details in file settings.js
// Author: Sven Dickmans, Autodesk

/* --------------------------------------------------------------------------------------------------------
    Change Log
    - 2022-01-21: Initial version
   -------------------------------------------------------------------------------------------------------- */


   const axios     = require('axios');
   const settings  = require('./settings.js');
   const utils     = require('./utils.js');
   
   
   utils.printStart([]);


utils.login(function() {
    getWorkflows('SYSTEM', function() {
        getWorkflows('TENANT', function() {
            getCustomers(function() {
                getDivisions(function() {
                    getProjectTypes(function() {
                        console.log();
                        utils.printEnd();
                    });
                });
            });
        });
    });
});


function getWorkflows(scope, callback) {
    
    axios.get('https://live.upchain.net/api/workflow/v1/workflows?limit=1000&status=Active&scope=' + scope).then(function (response) {
        
        console.log();
        console.log();
        console.log('    ' + scope + ' Workflow Types')
        utils.printLine();

        let types = utils.sort(response.data.content, 'type');
        for(type of types) {
            // console.log(type);
            console.log('    ' + type.type + ' : ' + type.name + ' version ' + type.version + ' (' + type.id + ')' + ' ' + type.status.toUpperCase());
        }

        callback();

    }).catch(function (error) {
        console.log(error);
    });
    
}


function getCustomers(callback) {
    
    axios.get('https://live.upchain.net/api/customer/v1/customers').then(function (response) {
        
        console.log();
        console.log();
        console.log('    Customers')
        utils.printLine();

        let items = utils.sort(response.data, 'customerName');
        for(item of items) {
            console.log('    ' + item.customerName + ' (' + item.id + ')' + ' ' + item.status.toUpperCase());
        }

        callback();

    }).catch(function (error) {
        console.log(error);
    });
    
}


function getDivisions(callback) {
    
    axios.get('https://live.upchain.net/api/division/v1/divisions').then(function (response) {
        
        console.log();
        console.log();
        console.log('    Divisions [name (id/num) status]');
        utils.printLine();

        let items = utils.sort(response.data, 'name');
        for(item of items) {
            console.log('    ' + item.name + ' (' + item.id + '/' + item.num + ')' + ' ' + item.status.toUpperCase());
        }

        callback();

    }).catch(function (error) {
        console.log(error);
    });
    
}


function getProjectTypes(callback) {
    
    axios.get('https://live.upchain.net/api/project-type/v1/types').then(function (response) {
        
        console.log();
        console.log();
        console.log('    Project Types')
        utils.printLine();

        let items = utils.sort(response.data, 'name');
        for(item of items) {
            console.log('    ' + item.name + ' (' + item.id + ')' + ' ' + item.status.toUpperCase());
        }

        callback();

    }).catch(function (error) {
        console.log(error);
    });
    
}