const axios         = require('axios');
const settings      = require("./settings.js");
const querystring   = require('querystring');


exports.printStart = function printStart(params) {

    console.log();
    console.log('   **************************** START ****************************');
    console.log('   ');
    console.log('    SETTINGS');
    console.log('   ---------------------------------------------------------------');
    console.log('    Client ID      : ' + settings.clientId); 
    console.log('    Company        : ' + settings.tenant); 
    console.log('    User Name      : ' + settings.username); 

    if(params !== null) {
        if(typeof params !== 'undefined') {
            for(param of params) {
                let line = '    ' + param[0];
                for(var i = param[0].length; i < 14; i++) line += ' ';
                line += ' : ' + param[1];
                console.log(line); 
            }
        }
    }

    console.log(); 

}


exports.login = function login(callback) {
    
    let params = {
        'grant_type'    : 'password',
        'client_id'     : settings.clientId,
        'client_secret' : settings.clientSecret,
        'username'      : settings.username,
        'password'      : settings.password
    }
    
    axios.post('https://live-sso.upchain.net/auth/realms/upchain/protocol/openid-connect/token', querystring.stringify(params)).then(function (response) {
        
        if(response.status === 200) {
            console.log('    Login successful');
            axios.defaults.headers.common['Authorization']  = "Bearer " + response.data.access_token;
            getCompany(function(companyID) {
                callback(companyID);
            });
        } else {
            console.log('    Login failed');   
            console.log('   ');
        }

    }).catch(function (error) {
        console.log(error);
    });
    
}
function getCompany(callback) {
    
    axios.get('https://live.upchain.net/api/auth/v1/companies').then(function (response) {
        
        if(response.data.length > 0)  {

            let companyID = '';
            
            for(company of response.data) {
                if(company.name === settings.tenant) {
                    console.log('    Found tenant/company ' + company.name + ' (' + company.id + ')');
                    axios.defaults.headers.common['Upc-Selected-Company']  = company.id;
                    companyID = company.id;
                    continue;
                }
            }

            if(companyID === '') {
                console.log();
                console.log('    ERROR: Could not find tenant/company with name "' + response.data[0].name + '"') ;
                console.log();
            } else {
                callback(companyID);
            }
            
        } else {
            console.log('    Coulld not find related companies');   
            console.log('   ');           
        }

    }).catch(function (error) {
        console.log(error);
    });
    
}




exports.sort = function sort(list, key) {

    list.sort(function(a, b){
        var nameA=a[key].toLowerCase(), nameB=b[key].toLowerCase()
        if (nameA < nameB) return -1 
        if (nameA > nameB) return 1
        return 0 
    });

    return list;

}


exports.printLine = function printLine() {
    console.log('   ---------------------------------------------------------------');
}


exports.printEnd = function printEnd() {

    console.log();
    console.log('   ***************************** END *****************************');
    console.log();

}